@@ -91,7 +91,7 @@ bool Glossary::load(const QString& newPath)
     }
 
     QXmlSimpleReader reader;
-    //reader.setFeature("http://qtsoftware.com/xml/features/report-whitespace-only-CharData",true);
+    reader.setFeature("http://qt-project.org/xml/features/report-whitespace-only-CharData",true);
     reader.setFeature("http://xml.org/sax/features/namespaces", false);
     QXmlInputSource source(device);
 
@@ -182,7 +182,6 @@ void GlossarySortFilterProxyModel::fetchMore(const QModelIndex&)
     int expectedCount = rowCount() + FETCH_SIZE / 2;
     while (rowCount(QModelIndex()) < expectedCount && sourceModel()->canFetchMore(QModelIndex())) {
         sourceModel()->fetchMore(QModelIndex());
-        //qCDebug(LOKALIZE_LOG)<<"filter:"<<rowCount(QModelIndex())<<"/"<<sourceModel()->rowCount();
         QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::ExcludeSocketNotifiers);
     }
 }
@@ -368,7 +367,6 @@ static void getElementsForTermLangIndex(QDomElement termEntry, QString& lang, in
     QString minusLang = lang; minusLang.replace('_', '-');
     QStringRef soleLang = lang.leftRef(2);
 
-    //qCDebug(LOKALIZE_LOG)<<"started walking over"<<lang<<index;
     QDomElement n = termEntry.firstChildElement(langSet);
     QDomDocument document = n.ownerDocument();
     int i = 0;
@@ -379,7 +377,6 @@ static void getElementsForTermLangIndex(QDomElement termEntry, QString& lang, in
             ourLangSetElement = n;
             QDomElement ntigElem = n.firstChildElement(ntig);
             while (!ntigElem.isNull()) {
-                //qCDebug(LOKALIZE_LOG)<<i<<ntigElem.firstChildElement(termGrp).firstChildElement(term).text();
                 if (i == index) {
                     tigElement = ntigElem;
                     termElement = ntigElem.firstChildElement(termGrp).firstChildElement(term);
