@@ -123,6 +123,7 @@ TranslationUnitTextEdit::TranslationUnitTextEdit(Catalog* catalog, DocPosition::
     , m_completionBox(0)
     , m_cursorSelectionStart(0)
     , m_cursorSelectionEnd(0)
+    , m_languageToolTimer(new QTimer(this))
 {
     setReadOnly(part == DocPosition::Source);
     setUndoRedoEnabled(false);
@@ -134,9 +135,11 @@ TranslationUnitTextEdit::TranslationUnitTextEdit(Catalog* catalog, DocPosition::
     if (part == DocPosition::Target) {
         connect(document(), &QTextDocument::contentsChange, this, &TranslationUnitTextEdit::contentsChanged);
         connect(this, &KTextEdit::cursorPositionChanged, this, &TranslationUnitTextEdit::emitCursorPositionChanged);
+        connect(m_languageToolTimer, &QTimer::timeout, this, &TranslationUnitTextEdit::launchLanguageTool);
     }
     connect(catalog, QOverload<>::of(&Catalog::signalFileLoaded), this, &TranslationUnitTextEdit::fileLoaded);
     //connect (Project::instance(), &Project::configChanged, this, &TranslationUnitTextEdit::projectConfigChanged);
+    m_languageToolTimer->setSingleShot(true);
 }
 
 void TranslationUnitTextEdit::setSpellCheckingEnabled(bool enable)
@@ -308,6 +311,10 @@ void TranslationUnitTextEdit::setContent(const CatalogString& catStr, const Cata
     else
         //reflectApprovementState() does this for Target
         m_highlighter->rehighlight(); //explicitly because the signals were disabled
+    if (Settings::self()->languageToolDelay() > 0)
+    {
+        m_languageToolTimer->start(Settings::self()->languageToolDelay() * 1000);
+    }
 }
 
 #if 0
@@ -526,6 +533,11 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         } else if (m_completionBox)
             m_completionBox->hide();
         //qCWarning(LOKALIZE_LOG)<<"finish";
+        //Start LanguageToolTimer
+        if (Settings::self()->languageToolDelay() > 0)
+        {
+            m_languageToolTimer->start(Settings::self()->languageToolDelay() * 1000);
+        }
     }
 
 
@@ -912,8 +924,6 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         return text;
     }
 
-
-
     void TranslationUnitTextEdit::emitCursorPositionChanged() {
         emit cursorPositionChanged(textCursor().columnNumber());
     }
@@ -1157,10 +1167,13 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
     }
 
     void TranslationUnitTextEdit::launchLanguageTool()     {
+        if (toPlainText().length() == 0)
+            return;
+
         LanguageToolResultJob *job = new LanguageToolResultJob(this);
         job->setUrl(LanguageToolManager::self()->languageToolCheckPath());
         job->setNetworkAccessManager(LanguageToolManager::self()->networkAccessManager());
-        job->setText(toPlainText());
+        job->setText(toPlainText().toHtmlEscaped().replace(QStringLiteral("%"), QStringLiteral("%25")));
         job->setLanguage(m_catalog->targetLangCode());
         connect(job, &LanguageToolResultJob::finished, this, &TranslationUnitTextEdit::slotLanguageToolFinished);
         connect(job, &LanguageToolResultJob::error, this, &TranslationUnitTextEdit::slotLanguageToolError);
